@@ -1,6 +1,6 @@
 /*
- *  Copyright (C) 2003 Marco Pesenti Gritti
- *  Copyright (C) 2003 Christian Persch
+ *  Copyright © 2003 Marco Pesenti Gritti
+ *  Copyright © 2003 Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -16,12 +16,10 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: extension.c,v 1.4 2004/12/08 15:33:52 chpe Exp $
+ *  $Id: extension.c,v 1.8 2006/09/13 19:01:04 chpe Exp $
  */
 
-#ifdef HAVE_CONFIG_H
 #include "config.h"
-#endif
 
 #include "ephy-adblock-extension.h"
 #include "ad-blocker.h"
@@ -35,7 +33,7 @@ G_MODULE_EXPORT GType register_module (GTypeModule *module);
 G_MODULE_EXPORT GType
 register_module (GTypeModule *module)
 {
-	LOG ("Registering EphyAdblockExtension")
+	LOG ("Registering EphyAdblockExtension");
 
 #ifdef ENABLE_NLS
        /* Initialise the i18n stuff */
@@ -44,5 +42,6 @@ register_module (GTypeModule *module)
 #endif /* ENABLE_NLS */
 
 	ad_blocker_register_type (module);
+	ad_uri_tester_register_type (module);
 	return ephy_adblock_extension_register_type (module);
 }
