@@ -1,7 +1,7 @@
 /*
- *  Copyright (C) 2001,2002,2003 Philip Langdale
- *  Copyright (C) 2003 Marco Pesenti Gritti
- *  Copyright (C) 2004 Adam Hooper
+ *  Copyright © 2001,2002,2003 Philip Langdale
+ *  Copyright © 2003 Marco Pesenti Gritti
+ *  Copyright © 2004 Adam Hooper
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,32 +17,27 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: register-listener.cpp,v 1.5 2004/12/08 15:33:52 chpe Exp $
+ *  $Id: register-listener.cpp,v 1.8 2006/09/13 19:01:08 chpe Exp $
  */
 
 #include "mozilla-config.h"
-
 #include "config.h"
 
-#include "ErrorViewerConsoleListener.h"
-
-#include <nsIServiceManager.h>
-#include <nsIConsoleService.h>
 #include <nsCOMPtr.h>
-#include <nsXPCOM.h>
+#include <nsIConsoleService.h>
 #include <nsNetCID.h>
+#include <nsServiceManagerUtils.h>
+#include <nsXPCOM.h>
 
-#include <glib-object.h>
+#include "ErrorViewerConsoleListener.h"
 
 extern "C" void *
 mozilla_register_error_listener (GObject *dialog)
 {
 	ErrorViewerConsoleListener *listener;
-	nsresult rv;
 
-	nsCOMPtr<nsIConsoleService> consoleService =
-		do_GetService (NS_CONSOLESERVICE_CONTRACTID, &rv);
-	g_return_val_if_fail (NS_SUCCEEDED (rv), NULL);
+	nsCOMPtr<nsIConsoleService> consoleService (do_GetService (NS_CONSOLESERVICE_CONTRACTID));
+	NS_ENSURE_TRUE (consoleService, NULL);
 
 	listener = new ErrorViewerConsoleListener ();
 	consoleService->RegisterListener (listener);
@@ -55,13 +50,10 @@ mozilla_register_error_listener (GObject *dialog)
 extern "C" void
 mozilla_unregister_error_listener (void *listener)
 {
-	nsresult rv;
+	NS_ENSURE_TRUE (listener, );
 
-	nsCOMPtr<nsIConsoleService> consoleService =
-		do_GetService (NS_CONSOLESERVICE_CONTRACTID, &rv);
-	g_return_if_fail (NS_SUCCEEDED (rv));
+	nsCOMPtr<nsIConsoleService> consoleService (do_GetService (NS_CONSOLESERVICE_CONTRACTID));
+	NS_ENSURE_TRUE (consoleService, );
 
 	consoleService->UnregisterListener ((ErrorViewerConsoleListener *) listener);
-
-	/* FIXME: Are we leaking the listener? */
 }
