@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004 Adam Hooper
+ *  Copyright © 2004 Adam Hooper
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -15,27 +15,25 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: validate.cpp,v 1.11 2004/09/22 20:03:51 adamh Exp $
+ *  $Id: validate.cpp,v 1.15 2006/09/13 19:01:09 chpe Exp $
  */
 
-#ifdef HAVE_CONFIG_H
 #include "config.h"
-#endif
-
-#include "validate.h"
-
-#include <OpenSP/config.h> // Necessary for multi-byte support
-#include <OpenSP/ParserEventGeneratorKit.h>
-
-#include "error-viewer.h"
 
 #include <sys/types.h>
 #include <regex.h>
 
 #include <glib/gi18n-lib.h>
 
-#include <iostream>
 #include <string>
+#include <iostream>
+
+#include <OpenSP/config.h> // Necessary for multi-byte support
+#include <OpenSP/ParserEventGeneratorKit.h>
+
+#include "error-viewer.h"
+
+#include "validate.h"
 
 using namespace std;
 
@@ -131,7 +129,7 @@ HtmlErrorFinder::handle_line (const char *msg)
 			     matches, 0);
 	if (regex_ret != 0)
 	{
-		g_warning ("Could not parse OpenSP string.: %s\n", msg);
+		g_warning ("Could not parse OpenSP string: %s\n", msg);
 		sgml_validator_append (this->mValidator,
 				       ERROR_VIEWER_ERROR,
 				       msg);
@@ -166,7 +164,7 @@ HtmlErrorFinder::handle_line (const char *msg)
 	description = msg + matches[5].rm_so;
 
 	verbose_msg =
-		g_strdup_printf (_("HTML error in %s on line %s:\n%s"),
+		g_strdup_printf (_("HTML error in “%s” on line %s:\n%s"),
 				 display_filename, line_number, description);
 
 	sgml_validator_append (this->mValidator, error_type, verbose_msg);
