@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004 Jean-François Rameau
+ *  Copyright © 2004 Jean-François Rameau
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: smart-bookmarks.c,v 1.3 2005/01/13 16:15:50 chpe Exp $
+ *  $Id: smart-bookmarks.c,v 1.5 2006/09/13 19:01:37 chpe Exp $
  */
 
 #include "config.h"
@@ -31,7 +31,7 @@ G_MODULE_EXPORT GType register_module (GTypeModule *module);
 G_MODULE_EXPORT GType
 register_module (GTypeModule *module)
 {
-	LOG ("Registering Smart Bookmarks Extension")
+	LOG ("Registering Smart Bookmarks Extension");
 
 #ifdef ENABLE_NLS
 	/* Initialise the i18n stuff */
